@@ -14,10 +14,10 @@ sub build_binaries {
 
   chdir "src/build/gmake";
   print "Gonna cd build/gmake & make install ...\n";
-  my $cmd = $self->get_make . " installhdrs installib installexes ".
-                              " runinst_prefix=$prefixdir devinst_prefix=$prefixdir CC=$Config{cc}";
-  print "[cmd: $cmd]\n";
-  $self->do_system($cmd) or die "###ERROR### [$?] during make ... ";
+  my @cmd = ($self->get_make, 'installhdrs', 'installib', 'installexes',
+                              "runinst_prefix=$prefixdir", "devinst_prefix=$prefixdir", "CC=$Config{cc}");
+  print "[cmd: ".join(' ',@cmd)."]\n";
+  $self->do_system(@cmd) or die "###ERROR### [$?] during make ... ";
   chdir $self->base_dir();
 
   return 1;
@@ -28,9 +28,9 @@ sub make_clean {
 
   chdir "src/build/gmake";
   print "Gonna cd build/gmake & make clean\n";
-  my $cmd = $self->get_make . " clean";
-  print "[cmd: $cmd]\n";
-  $self->do_system($cmd) or warn "###WARN### [$?] during make ... ";
+  my @cmd = ($self->get_make, 'clean');
+  print "[cmd: ".join(' ',@cmd)."]\n";
+  $self->do_system(@cmd) or warn "###WARN### [$?] during make ... ";
   chdir $self->base_dir();
 
   return 1;
@@ -47,4 +47,10 @@ sub get_make {
   return 'make';
 }
 
+sub quote_literal {
+    my ($self, $txt) = @_;
+    $txt =~ s|'|'\\''|g;
+    return "'$txt'";
+}
+
 1;
